@@ -41,6 +41,7 @@ DEFAULT_MAX_SQUEAKS = 10000
 DEFAULT_MAX_SQUEAKS_PER_PUBLIC_KEY_PER_BLOCK = 100
 DEFAULT_SERVER_RPC_HOST = "0.0.0.0"
 DEFAULT_SERVER_RPC_PORT = None
+DEFAULT_EXTERNAL_PORT = 8555
 DEFAULT_ADMIN_RPC_HOST = "0.0.0.0"
 DEFAULT_ADMIN_RPC_PORT = 8994
 DEFAULT_WEBADMIN_HOST = "0.0.0.0"
@@ -62,7 +63,7 @@ DEFAULT_INTEREST_BLOCK_INTERVAL = 2016
 DEFAULT_SENT_OFFER_RETENTION_S = 86400
 DEFAULT_RECEIVED_OFFER_RETENTION_S = 86400
 DEFAULT_OFFER_DELETION_INTERVAL_S = 10
-DEFAULT_PEER_AUTOCONNECT_INTERVAL_S = 10
+DEFAULT_PEER_DOWNLOAD_INTERVAL_S = 30
 DEFAULT_SUBSCRIBE_INVOICES_RETRY_S = 10
 DEFAULT_SQUEAK_RETENTION_S = 604800
 DEFAULT_SQUEAK_DELETION_INTERVAL_S = 10
@@ -103,6 +104,8 @@ class ServerConfig(Config):
     host = key(cast=str, required=False, default=DEFAULT_SERVER_RPC_HOST)
     port = key(cast=int, required=False, default=DEFAULT_SERVER_RPC_PORT)
     external_address = key(cast=str, required=False, default="")
+    external_port = key(cast=int, required=False,
+                        default=DEFAULT_EXTERNAL_PORT)
 
 
 @section('rpc')
@@ -152,8 +155,8 @@ class NodeConfig(Config):
         cast=int, required=False, default=DEFAULT_OFFER_DELETION_INTERVAL_S)
     interest_block_interval = key(
         cast=int, required=False, default=DEFAULT_INTEREST_BLOCK_INTERVAL)
-    peer_autoconnect_interval_s = key(
-        cast=int, required=False, default=DEFAULT_PEER_AUTOCONNECT_INTERVAL_S)
+    peer_download_interval_s = key(
+        cast=int, required=False, default=DEFAULT_PEER_DOWNLOAD_INTERVAL_S)
 
 
 @section('db')
