@@ -58,8 +58,14 @@ def create_app(handler):
 
     @app.route('/squeak/<hash>')
     def squeak(hash):
-        squeak_bytes = handler.handle_get_squeak_bytes(hash)
-        return squeak_bytes
+        try:
+            squeak_type, squeak_bytes = handler.handle_get_squeak_bytes(hash)
+        except NotFoundError:
+            return "Not found", 404
+        return jsonify({
+            'squeak_type': squeak_type,
+            'squeak_bytes': squeak_bytes.hex(),
+        })
 
     @app.route('/secretkey/<hash>')
     def secret_key(hash):
